<?php 
/**
 * Contains all Takeoff theme functions.
 *
 * @package Takeoff
 * @since Takeoff 1.0
 */



/* Registering scripts.
================================================== */
  function takeoff_scripts() {

    wp_enqueue_script(
      'custom-script',
      get_stylesheet_directory_uri() . '/js/bootstrap.js',
      array( 'jquery' )
    );

    wp_enqueue_style(
      'takeoff-style',
      get_stylesheet_directory_uri() . '/style.css',
      array( 'takeoff-bootstrap' )
    );

    wp_enqueue_style( 
      'takeoff-bootstrap', 
      get_stylesheet_directory_uri() . '/css/bootstrap.css' 
    );

  if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
    wp_enqueue_script( 'comment-reply' );
  

  }
    add_action( 'wp_enqueue_scripts', 'takeoff_scripts' );



/* Loads the Options Panel found under the Appearance tab.
================================================== */

    define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/theme-options/' );
    require_once dirname( __FILE__ ) . '/theme-options/options-framework.php';
    require_once( get_template_directory() . '/theme-options/options-functions.php' );



/* Sets up theme defaults and registers support for various WordPress features.
================================================== */

function takeoff_setup() {

// Translation Ready. Translations can be filed in the /languages/ directory.
    load_theme_textdomain( 'takeoff', get_template_directory() . '/languages' );

// Add Feed links
    add_theme_support( 'automatic-feed-links' );

//Show Featured Images
    add_theme_support( 'post-thumbnails' );
    add_image_size( 'latest-thumb', 560, 320, true );
    add_image_size( 'post-thumb', 250, 250, true );
    add_image_size( 'keepreading-thumb', 394, 262, true );

// Register the Navigation Menu
    register_nav_menu( 'primary', __( 'Primary Menu', 'takeoff' ) );

// Max width of embeds, images, videos and other objects
    global $content_width;
      if (!isset($content_width)) {
        $content_width = 870;
      }

}
add_action( 'after_setup_theme', 'takeoff_setup' );



/* Register Pagination and Custom Navigation Walker
================================================== */

require_once('wp_bootstrap_navwalker.php');
require_once('pagination.php');



/* Registers Sidebar
================================================== */

    if ( function_exists('register_sidebar') )
    	register_sidebar(array(
      'name' => __( 'Primary Sidebar', 'takeoff' ),
      'description' => __( 'Takeoff has a simple Sidebar which appears on all posts and pages. Each widget is placed inside a panel allowing easy readability.', 'takeoff' ),
    		'before_widget' => '<div class="panel panel-default panel-body">',
    		'after_widget' => '</div>',
    		'before_title' => '<h3 class="sidebar-heading">',
    		'after_title' => '</h3>'
    	));




/* Excerpts
================================================== */

// Custom Excerpt Length
function takeoff_custom_excerpt_length( $length ) {
    return 50;
}
add_filter( 'excerpt_length', 'takeoff_custom_excerpt_length', 999 );


// Read More Button under excerpts
function takeoff_custom_excerpt_more($more) {
  global $post;
    return '&#8230; <a href="'. get_permalink($post->ID) . '">' . '<br><br><button type="button" class="btn btn-default">Читать далее <span class="glyphicon glyphicon-chevron-right"></span></button>' . '</a>';
}
add_filter('excerpt_more', 'takeoff_custom_excerpt_more');


// Excerpt text limit for Continue Reading section under posts
function excerpt($limit) {
    $excerpt = explode(' ', get_the_excerpt(), $limit);
    if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
    } else {
    $excerpt = implode(" ",$excerpt);
    } 
    $excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
    return $excerpt;
}



/* Google Font Styles found in Options Panel > Typography
================================================== */

function ggl_load_styles() {
    if (!is_admin()) {
    wp_register_style('googleFont', '//fonts.googleapis.com/css?family=Roboto|Lato');
    wp_enqueue_style('ggl', get_stylesheet_uri(), array('googleFont') );
    }
    }
    add_action('wp_enqueue_scripts', 'ggl_load_styles');



/* Continue Reading (Next and Previous Post) Section variables
================================================== */

    function func_prevPost(){
      $prevPost = get_previous_post();
      return $prevPost;
    }

    function func_prevthumbnail(){
      $prevPost = get_previous_post();
      $prevthumbnail = get_the_post_thumbnail($prevPost->ID, 'keepreading-thumb');
      return $prevthumbnail;
    }

    function func_nextPost(){
      $nextPost = get_next_post();
      return $nextPost;
    }

    function func_nextthumbnail(){
      $nextPost = get_next_post();
      $nextthumbnail = get_the_post_thumbnail($nextPost->ID, 'keepreading-thumb');
      return $nextthumbnail;
    }



/* Add breadcrumbs functionality to your WordPress theme
================================================== */

function takeoff_breadcrumbs() {
  if(!is_home()) {
    echo '<nav class="breadcrumb">';
    if (is_category() || is_single()) {
      the_category(' <span class="divider"> &gt; </span> ');
      if (is_single()) {
        echo ' <span class="divider"> &gt; </span> ';
        the_title();
      }
    } elseif (is_page()) {
      echo the_title();
    }
    echo '</nav>';
  }
}



/* Site Title
================================================== */

// Source: http://bavotasan.com/2012/filtering-wp_title-for-better-seo/

add_filter( 'wp_title', 'filter_wp_title' );
function filter_wp_title( $title ) {
  global $page, $paged;

  if ( is_feed() )
    return $title;

  $site_description = get_bloginfo( 'description' );

  $filtered_title = $title . get_bloginfo( 'name' );
  $filtered_title .= ( ! empty( $site_description ) && ( is_home() || is_front_page() ) ) ? ' - ' . $site_description: '';
  $filtered_title .= ( 2 <= $paged || 2 <= $page ) ? ' - ' . sprintf( __( 'Страница %s', 'takeoff' ), max( $paged, $page ) ) : '';

  return $filtered_title;
}



/* Archives by Date variables
================================================== */
function func_archive_year(){
  $archive_year = get_the_time('Y');
  return $archive_year;
}

function func_archive_month(){
  $archive_month = get_the_time('m');
  return $archive_month;
}

function func_archive_day(){
  $archive_day = get_the_time('d');
  return $archive_day;
}



/* Commenting Function
================================================== */

// Taken from WordPress TwentyTwelve Theme

if ( ! function_exists( 'takeoff_comment' ) ) :

function takeoff_comment( $comment, $args, $depth ) {
  $GLOBALS['comment'] = $comment;
  switch ( $comment->comment_type ) :
    case 'pingback' :
    case 'trackback' :
    // Display trackbacks differently than normal comments.
  ?>
  <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
    <p><?php _e( 'Pingback:', 'takeoff' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Редактировать)', 'takeoff' ), '<span class="edit-link">', '</span>' ); ?></p>
  <?php
      break;
    default :
    // Proceed with normal comments.
    global $post;
  ?>
  <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
    <article id="comment-<?php comment_ID(); ?>" class="comment">
      <header class="comment-meta comment-author vcard">
        <?php
          echo get_avatar( $comment, 44 );
          printf( '<cite><b class="fn">%1$s</b> %2$s</cite>',
            get_comment_author_link(),
            // If current post author is also comment author, make it known visually.
            ( $comment->user_id === $post->post_author ) ? '<span class="post-author">' . __( 'Автор', 'takeoff' ) . '</span>' : ''
          );
          printf( '<br><a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
            esc_url( get_comment_link( $comment->comment_ID ) ),
            get_comment_time( 'c' ),
            /* translators: 1: date, 2: time */
            sprintf( __( '%1$s - %2$s', 'takeoff' ), get_comment_date(), get_comment_time() )
          );
        ?>
      </header><!-- .comment-meta -->

      <?php if ( '0' == $comment->comment_approved ) : ?>
        <p><?php _e( 'Ваш комментарий ожидает модерации.', 'takeoff' ); ?></p>
      <?php endif; ?>

      <section class="comment-content comment">
        <?php comment_text(); ?>
        <?php edit_comment_link( __( 'Редактировать', 'takeoff' ), '<p class="edit-link">', '</p>' ); ?>
      </section><!-- .comment-content -->

      <div>
        <?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Ответить', 'takeoff' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
      </div><!-- .reply -->
    </article><!-- #comment-## -->
  <?php
    break;
  endswitch; // end comment_type check
}
endif;

?>