<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'takeoff'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {


	$options[] = array(
		'name' => __('Post Settings', 'takeoff'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Breadcrumbs', 'takeoff'),
		'desc' => __('Check this box to show breadcrumbs under your post title.', 'takeoff'),
		'id' => 'breadcrumbs_checkbox',
		'std' => '0',
		'type' => 'checkbox');
	
	$options[] = array(
		'name' => __('Tags', 'takeoff'),
		'desc' => __('Check this box to show tags under your blog posts.', 'takeoff'),
		'id' => 'tags_checkbox',
		'std' => '1',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Categories', 'takeoff'),
		'desc' => __('Check this box to show categories under your post content.', 'takeoff'),
		'id' => 'categories_checkbox',
		'std' => '1',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Author Info Box', 'takeoff'),
		'desc' => __('Check this box to show the author info box under your post content.', 'takeoff'),
		'id' => 'author_info_checkbox',
		'std' => '1',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Next/Previous Posts Section', 'takeoff'),
		'desc' => __('Check this box to show the Next and Previous posts under your post content.', 'takeoff'),
		'id' => 'nextprev_checkbox',
		'std' => '1',
		'type' => 'checkbox');




	$options[] = array(
		'name' => __('Typography', 'takeoff'),
		'type' => 'heading');

	$font_faces = array(
		'Arial, sans-serif' => 'Arial',
        'Roboto, sans-serif' => 'Roboto',
		'Lato, sans-serif' => 'Lato');

	//Sitewide Font Style
	$options[] = array(
		'name' => __('Default Font Style', 'takeoff'),
	    'desc' => __('Choose a Default Font Style for your website.', 'takeoff'),
		'id' => 'global_font_style',
		'type' => 'select',
		'std' => 'Lato, sans-serif',
		'options' => $font_faces );




	$options[] = array(
		'name' => __('Social Links', 'takeoff'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Check this box to show Social Icons in the footer section. Add the complete profile URL including "http:// or https://"', 'takeoff'),
		'id' => 'enable_social_checkbox',
		'std' => '1',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Facebook', 'takeoff'),
		'desc' => __('Enable Facebook icon. Add your Profile URL below.', 'takeoff'),
		'id' => 'facebook_checkbox',
		'std' => '1',
		'type' => 'checkbox');

    $options[] = array(
		'id' => 'facebook_url',
		'type' => 'text');

	$options[] = array(
		'name' => __('Twitter', 'takeoff'),
		'desc' => __('Enable Twitter icon. Add your Profile URL below.', 'takeoff'),
		'id' => 'twitter_checkbox',
		'std' => '1',
		'type' => 'checkbox');

    $options[] = array(
		'id' => 'twitter_url',
		'type' => 'text');

	$options[] = array(
		'name' => __('Google Plus', 'takeoff'),
		'desc' => __('Enable Google Plus icon. Add your Profile URL below.', 'takeoff'),
		'id' => 'googleplus_checkbox',
		'std' => '1',
		'type' => 'checkbox');

    $options[] = array(
		'id' => 'googleplus_url',
		'type' => 'text');

	$options[] = array(
		'name' => __('LinkedIn', 'takeoff'),
		'desc' => __('Enable LinkedIn icon. Add your Profile URL below.', 'takeoff'),
		'id' => 'linkedin_checkbox',
		'std' => '1',
		'type' => 'checkbox');

    $options[] = array(
		'id' => 'linkedin_url',
		'type' => 'text');

	$options[] = array(
		'name' => __('YouTube', 'takeoff'),
		'desc' => __('Enable YouTube icon. Add your Profile URL below.', 'takeoff'),
		'id' => 'youtube_checkbox',
		'std' => '1',
		'type' => 'checkbox');

    $options[] = array(
		'id' => 'youtube_url',
		'type' => 'text');

	$options[] = array(
		'name' => __('Pinterest', 'takeoff'),
		'desc' => __('Enable Pinterest icon. Add your Profile URL below.', 'takeoff'),
		'id' => 'pinterest_checkbox',
		'std' => '1',
		'type' => 'checkbox');

    $options[] = array(
		'id' => 'pinterest_url',
		'type' => 'text');




	$options[] = array(
		'name' => __('Go PRO', 'takeoff'),
		'type' => 'heading');

	$options[] = array(
	'desc' => sprintf(
			'<p style="color: #1E90FF; font-size: 30px; margin-top:5px;">%s</p><p style="font-size: 20px; margin-top:5px;">%s</p><ul><li>-- %s</li><li>-- %s</li><li>-- %s</li><li>-- %s</li><li>-- %s</li><li>-- %s</li><li>-- %s</li><li>-- %s</li></ul><p style="color: #008000; font-size: 20px; margin-top:5px;">%s</p>',
			sprintf(
				__( 'Get Takeoff Pro for just $14.95', 'takeoff' )
			),
			sprintf(
				__( 'Features you get with the PRO version - ', 'takeoff' )
			),
			__( 'A Homepage carousel where you can add up to 5 slider images with links.', 'takeoff' ),
			__( 'Over 25 different Google Fonts to choose from.', 'takeoff' ),
			__( 'Advanced typography settings allowing you to change font size and color of any text on your website.', 'takeoff' ),
			__( 'Upload your own brand logo and a favicon.', 'takeoff' ),
			__( 'Add your own footer text and create a widget area.', 'takeoff' ),
			__( 'Three types of Blog Posts templates.', 'takeoff' ),
			__( 'Optional Front Business Page with featured areas having text and images.', 'takeoff' ),
			__( 'And many more amazing features.', 'takeoff' ),
			sprintf(
					__( '<a href="%s">Know More...</a>', 'takeoff' ),
					esc_url( 'http://novicepost.com/takeoff-pro-theme/' )
				)
		),
	'type' => 'info');





	$options[] = array(
		"name" => __( 'More', 'takeoff' ),
		"type" => "heading"
	);

	$options[] = array(
		'name' => __( 'Theme Support', 'takeoff' ),
		'desc' => sprintf(
				'<p>%s</p>',
				sprintf(
					__( 'If you need help with Takeoff, check if your question has been answered in the <a href="%s">theme FAQ</a>. If not, ask in the WordPress Support Forums and we will be sure to answer your questions.', 'takeoff' ),
					esc_url( 'http://novicepost.com/takeoff-theme/' )
				)
			),
		'type' => 'info'
	);

	$options[] = array(
		'name' => __( 'How you can help', 'takeoff' ),
		'desc' => sprintf(
				'<p>%s</p><p>%s</p>',
				sprintf(
					__( 'If you like this theme and would like to support further development, consider making a <a href="%s">small donation</a>.', 'takeoff' ),
					esc_url( 'http://novicepost.com/takeoff-theme/' )
				),
				sprintf(
					__( 'You can also check out <a href="%s">Takeoff Pro</a>. Click the "GO PRO" tab above for a glimpse of all the great features you will get. Also, a part of everything we earn is donated to the CRY(Child Rights and You) Foundation. That way, we both help for a good cause... :)', 'takeoff' ),
					esc_url( 'http://novicepost.com/takeoff-pro-theme/' )
				)
			),
		'type' => 'info'
	);
	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	return $options;
}